@@ -4,15 +4,16 @@ import sys
 from collections import defaultdict
 from typing import DefaultDict
 
-from drf_spectacular.settings import spectacular_settings
-
 
 class GeneratorStats:
     _warn_cache: DefaultDict[str, int] = defaultdict(int)
     _error_cache: DefaultDict[str, int] = defaultdict(int)
 
-    def __init__(self):
-        self.silent = spectacular_settings.DISABLE_ERRORS_AND_WARNINGS
+    def __getattr__(self, name):
+        if not self.__dict__:
+            from drf_spectacular.settings import spectacular_settings
+            self.silent = spectacular_settings.DISABLE_ERRORS_AND_WARNINGS
+        return getattr(self, name)
 
     def __bool__(self):
         return bool(self._warn_cache or self._error_cache)
@@ -113,3 +114,8 @@ def get_view_methods(view, schema=None):
             or hasattr(getattr(view, item), 'mapping')
         )
     ]
+
+
+def cache(user_function):
+    """ simple polyfill for python < 3.9 """
+    return functools.lru_cache(maxsize=None)(user_function)
