@@ -1,6 +1,7 @@
 import functools
 import inspect
-from typing import Any, Callable, Dict, List, Optional, Type, TypeVar, Union
+import sys
+from typing import Any, Callable, Dict, List, Optional, Tuple, Type, TypeVar, Union
 
 from rest_framework.fields import Field, empty
 from rest_framework.serializers import Serializer
@@ -9,8 +10,16 @@ from rest_framework.settings import api_settings
 from drf_spectacular.drainage import error, get_view_methods, set_override, warn
 from drf_spectacular.types import OpenApiTypes, _KnownPythonTypes
 
+if sys.version_info >= (3, 8):
+    from typing import Final, Literal
+else:
+    from typing_extensions import Final, Literal
+
+
 _SerializerType = Union[Serializer, Type[Serializer]]
 
+_ParameterLocationType = Literal['query', 'path', 'header', 'cookie']
+
 
 class PolymorphicProxySerializer(Serializer):
     """
@@ -100,8 +109,9 @@ class OpenApiExample(OpenApiSchemaBase):
             description: str = '',
             request_only: bool = False,
             response_only: bool = False,
+            parameter_only: Optional[Tuple[str, _ParameterLocationType]] = None,
             media_type: str = 'application/json',
-            status_codes: Optional[List[str]] = None
+            status_codes: Optional[List[str]] = None,
     ):
         self.name = name
         self.summary = summary
@@ -110,6 +120,7 @@ class OpenApiExample(OpenApiSchemaBase):
         self.external_value = external_value
         self.request_only = request_only
         self.response_only = response_only
+        self.parameter_only = parameter_only
         self.media_type = media_type
         self.status_codes = status_codes or ['200', '201']
 
@@ -125,16 +136,16 @@ class OpenApiParameter(OpenApiSchemaBase):
     For valid ``style`` choices please consult the
     `OpenAPI specification <https://swagger.io/specification/#style-values>`_.
     """
-    QUERY = 'query'
-    PATH = 'path'
-    HEADER = 'header'
-    COOKIE = 'cookie'
+    QUERY: Final = 'query'
+    PATH: Final = 'path'
+    HEADER: Final = 'header'
+    COOKIE: Final = 'cookie'
 
     def __init__(
             self,
             name: str,
             type: Union[_SerializerType, _KnownPythonTypes, OpenApiTypes, dict] = str,
-            location: str = QUERY,
+            location: _ParameterLocationType = QUERY,
             required: bool = False,
             description: str = '',
             enum: Optional[List[Any]] = None,
@@ -143,6 +154,7 @@ class OpenApiParameter(OpenApiSchemaBase):
             explode: Optional[bool] = None,
             default: Any = None,
             examples: Optional[List[OpenApiExample]] = None,
+            extensions: Optional[Dict[str, Any]] = None,
             exclude: bool = False,
             response: Union[bool, List[Union[int, str]]] = False,
     ):
@@ -157,6 +169,7 @@ class OpenApiParameter(OpenApiSchemaBase):
         self.explode = explode
         self.default = default
         self.examples = examples or []
+        self.extensions = extensions
         self.exclude = exclude
         self.response = response
 
@@ -199,6 +212,7 @@ def extend_schema(
         methods: Optional[List[str]] = None,
         versions: Optional[List[str]] = None,
         examples: Optional[List[OpenApiExample]] = None,
+        extensions: Optional[Dict[str, Any]] = None,
 ) -> Callable[[F], F]:
     """
     Decorator mainly for the "view" method kind. Partially or completely overrides
@@ -244,6 +258,7 @@ def extend_schema(
     :param methods: scope extend_schema to specific methods. matches all by default.
     :param versions: scope extend_schema to specific API version. matches all by default.
     :param examples: attach request/response examples to the operation
+    :param extensions: specification extensions, e.g. ``x-badges``, ``x-code-samples``, etc.
     :return:
     """
     def decorator(f):
@@ -297,7 +312,7 @@ def extend_schema(
 
             def get_examples(self):
                 if examples and is_in_scope(self):
-                    return examples
+                    return super().get_examples() + examples
                 return super().get_examples()
 
             def get_request_serializer(self):
@@ -330,6 +345,11 @@ def extend_schema(
                     return tags
                 return super().get_tags()
 
+            def get_extensions(self):
+                if extensions and is_in_scope(self):
+                    return extensions
+                return super().get_extensions()
+
         if inspect.isclass(f):
             # either direct decoration of views, or unpacked @api_view from OpenApiViewExtension
             if operation_id is not None or operation is not None:
@@ -402,6 +422,7 @@ def extend_schema_serializer(
         exclude_fields: Optional[List[str]] = None,
         deprecate_fields: Optional[List[str]] = None,
         examples: Optional[List[OpenApiExample]] = None,
+        extensions: Optional[Dict[str, Any]] = None,
         component_name: Optional[str] = None,
 ) -> Callable[[F], F]:
     """
@@ -414,6 +435,7 @@ def extend_schema_serializer(
         schema. fields will still be exposed through the API.
     :param deprecate_fields: fields to mark as deprecated while processing the serializer.
     :param examples: define example data to serializer.
+    :param extensions: specification extensions, e.g. ``x-is-dynamic``, etc.
     :param component_name: override default class name extraction.
     """
     def decorator(klass):
@@ -425,6 +447,8 @@ def extend_schema_serializer(
             set_override(klass, 'deprecate_fields', deprecate_fields)
         if examples:
             set_override(klass, 'examples', examples)
+        if extensions:
+            set_override(klass, 'extensions', extensions)
         if component_name:
             set_override(klass, 'component_name', component_name)
         return klass
