@@ -97,13 +97,16 @@ def test_spectacular_view_accept_unknown(no_warnings):
 @pytest.mark.parametrize('ui', ['redoc', 'swagger-ui'])
 @pytest.mark.urls(__name__)
 def test_spectacular_ui_view(no_warnings, ui):
+    from drf_spectacular.settings import spectacular_settings
     response = APIClient().get(f'/api/v2/schema/{ui}/')
     assert response.status_code == 200
     assert response.content.startswith(b'<!DOCTYPE html>')
     if ui == 'redoc':
         assert b'<title>ReDoc</title>' in response.content
+        assert spectacular_settings.REDOC_DIST.encode() in response.content
     else:
         assert b'<title>Swagger</title>' in response.content
+        assert spectacular_settings.SWAGGER_UI_DIST.encode() in response.content
     assert b'"/api/v2/schema/"' in response.content
 
 
